"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getAffiliationFuHuaQi = exports.outPutEnterpriseData = exports.enterpriseList = exports.deleteEnterpriseByUscc = exports.getEnterpriseByUscc = exports.updateMoveInEnterprise = exports.moveInEnterprise = exports.updateRegisterEnterprise = exports.registerEnterprise = void 0;
/**
 * 企业相关逻辑
 * 作者: 李欣鸣
 * 包括新注册企业，迁入企业
 *
 */
const checkParamConfig_1 = require("../../config/checkParamConfig");
const errorEnum_1 = require("../../config/errorEnum");
const ojbectResultKeyConfig_1 = require("../../config/ojbectResultKeyConfig");
const bizError_1 = require("../../util/bizError");
const tools_1 = require("../../util/tools");
const enterprise_1 = require("../../data/enterprise/enterprise");
const ojbectResultKeyConfig_2 = require("../../config/ojbectResultKeyConfig");
const fuhuaqi_1 = require("../../data/fuHuaQi/fuhuaqi");
const enum_1 = require("../../config/enum");
/**
 * 新注册企业
 * 小程序端
 * @param uscc 孵化器统一信用代码
 * @param param 表单参数
 * @returns {isSuccess:true/false}
 */
async function registerEnterprise(uscc, param) {
    const TaskId = tools_1.getTaskId(uscc);
    tools_1.checkParamater("新注册企业", checkParamConfig_1.RegisterEnterpriseParamConfig, param); //校验表单参数
    let dataBaseInfo = await enterprise_1.findEnterpriseByUscc(param.uscc);
    if (dataBaseInfo && dataBaseInfo.uscc)
        throw new bizError_1.BizError(errorEnum_1.ERRORENUM.该企业已存在, `${param.uscc}已经在库中存在`);
    param.isCreate = true; //标识此次操作是否是新注册企业并不是迁入企业
    await enterprise_1.createEnterprise(uscc, TaskId, param);
    return { isSuccess: true };
}
exports.registerEnterprise = registerEnterprise;
/**
 * 修改新注册企业的表单
 * 小程序端
 * @param uscc 孵化器统一信用代码
 * @param param 表单参数
 * @returns {isSuccess:true/false}
 */
async function updateRegisterEnterprise(uscc, param) {
    tools_1.checkParamater("新注册企业表单修改", checkParamConfig_1.RegisterEnterpriseParamConfig, param); //校验表单参数
    let dataBaseInfo = await enterprise_1.findEnterpriseByUscc(param.uscc);
    if (!dataBaseInfo || !dataBaseInfo.uscc)
        throw new bizError_1.BizError(errorEnum_1.ERRORENUM.未找到数据, `库中不存在${param.uscc}这个企业`);
    let changeList = tools_1.checkChange(param, dataBaseInfo); //比对修改字段
    if (!changeList.length)
        throw new bizError_1.BizError(errorEnum_1.ERRORENUM.数据无更新, `${param.uscc}数据无更新`);
    changeList.forEach(key => {
        dataBaseInfo[key] = param[key];
    });
    await dataBaseInfo.save();
    return { isSuccess: true };
}
exports.updateRegisterEnterprise = updateRegisterEnterprise;
/**
 * 迁入企业登记
 * 小程序端
 * @param uscc 孵化器统一信用代码
 * @param param 表单参数
 * @returns {isSuccess:true/false}
 */
async function moveInEnterprise(uscc, param) {
    const TaskId = tools_1.getTaskId(uscc);
    tools_1.checkParamater("迁入企业登记", checkParamConfig_1.MoveInEnterpriseParamConfig, param); //校验表单参数
    let dataBaseInfo = await enterprise_1.findEnterpriseByUscc(param.uscc);
    if (dataBaseInfo && dataBaseInfo.uscc)
        throw new bizError_1.BizError(errorEnum_1.ERRORENUM.该企业已存在, `${param.uscc}已经在库中存在`);
    await enterprise_1.createEnterprise(uscc, TaskId, param);
    return { isSuccess: true };
}
exports.moveInEnterprise = moveInEnterprise;
/**
 * 修改迁入企业登记信息
 * 小程序端
 * @param uscc 孵化器统一信用代码
 * @param param 表单参数
 * @returns {isSuccess:true/false}
 */
async function updateMoveInEnterprise(uscc, param) {
    tools_1.checkParamater("修改迁入企业登记信息", checkParamConfig_1.MoveInEnterpriseParamConfig, param); //校验表单参数
    let dataBaseInfo = await enterprise_1.findEnterpriseByUscc(param.uscc);
    if (!dataBaseInfo || !dataBaseInfo.uscc)
        throw new bizError_1.BizError(errorEnum_1.ERRORENUM.未找到数据, `库中不存在${param.uscc}这个企业`);
    let changeList = tools_1.checkChange(param, dataBaseInfo);
    if (!changeList.length)
        throw new bizError_1.BizError(errorEnum_1.ERRORENUM.数据无更新, `${param.uscc}数据无更新`);
    changeList.forEach(key => {
        dataBaseInfo[key] = param[key];
    });
    await dataBaseInfo.save();
    return { isSuccess: true };
}
exports.updateMoveInEnterprise = updateMoveInEnterprise;
/**
 * 根据企业id查询企业信息
 * 小程序端  回显
 * @param uscc 企业统一信用代码
 */
async function getEnterpriseByUscc(uscc) {
    let dataBaseInfo = await enterprise_1.findEnterpriseByUscc(uscc);
    if (!dataBaseInfo || !dataBaseInfo.uscc)
        throw new bizError_1.BizError(errorEnum_1.ERRORENUM.未找到数据, `库中不存在${uscc}这个企业`);
    let data = tools_1.extractData(ojbectResultKeyConfig_1.EnterpriseInfoConfig, dataBaseInfo, false);
    return { data };
}
exports.getEnterpriseByUscc = getEnterpriseByUscc;
/**
 * 根据企业id删除草稿企业
 * 小程序端
 * @param uscc 企业统一信用代码
 */
async function deleteEnterpriseByUscc(uscc) {
    let dataBaseInfo = await enterprise_1.findEnterpriseByUscc(uscc);
    if (!dataBaseInfo || !dataBaseInfo.uscc)
        throw new bizError_1.BizError(errorEnum_1.ERRORENUM.未找到数据, `库中不存在${uscc}这个企业`);
    if (dataBaseInfo.draftLock)
        throw new bizError_1.BizError(errorEnum_1.ERRORENUM.已入库的数据不能删除, uscc);
    await enterprise_1.deleteEnterprise(uscc);
    return { isSuccess: true };
}
exports.deleteEnterpriseByUscc = deleteEnterpriseByUscc;
/**
 * 获取在孵企业信息列表
 * 管理后台端
 * @param createType 新注册/迁入  1:全选 2:新注册 3:迁入   以前是时间  2/23日修改为类型
 * @param fuHuaQiUscc 所属孵化器
 * @param industry 行业领域
 * @param isNaturalPersonHolding 自然人控股
 * @param page 页数
 * @returns {dataList:[], count:0}  dataList=数据列表  count:条件筛选下的数据总数
 */
async function enterpriseList(createType, fuHuaQiUscc, industry, isNaturalPersonHolding, page) {
    let selectParam = {};
    // if ( time.length > 0 ) {
    //     let startT = moment(time).startOf('month').valueOf();
    //     let endT = moment(time).endOf('month').valueOf();
    //     selectParam['$or'] = [
    //         {"firstIncubationTime":{'$gt':startT, '$lt':endT}},
    //         {"timeOfImmigration":{'$gt':startT, '$lt':endT}},
    //     ];
    // }
    // if (time) selectParam.logonTime = time; selectParam.timeOfImmigration = time;
    if (createType == 2 || createType == 3) {
        selectParam.createType = createType == 2 ? true : false;
    }
    if (fuHuaQiUscc)
        selectParam.fuHuaQiUscc = fuHuaQiUscc;
    if (industry.length > 0)
        selectParam.industry = industry;
    if (isNaturalPersonHolding == 2 || isNaturalPersonHolding == 3) {
        selectParam.isNaturalPersonHolding = isNaturalPersonHolding == 2 ? true : false;
    }
    let usccMap = await fuhuaqi_1.findAllFuHuaQiOperationNameMap();
    let dataBaseList = await enterprise_1.findEnterpriseListToPage(selectParam, (page - 1) * 10);
    let count = await enterprise_1.findEnterpriseCount(selectParam);
    let dataList = [];
    dataBaseList.forEach(info => {
        let changeData = tools_1.extractData(ojbectResultKeyConfig_2.EnterpriseListConfig, info, true);
        changeData.fuhuaqiUscc = usccMap[changeData.fuhuaqiUscc] || "";
        (changeData.isCreate) ? changeData.isCreate = "新注册" : changeData.isCreate = "新迁入";
        changeData.industry = tools_1.changeEnumValue(enum_1.FUHUAINDUSTRY, changeData.industry);
        dataList.push(changeData);
    });
    return { count, dataList };
}
exports.enterpriseList = enterpriseList;
/**
 * 导出在孵企业信息列表
 * 管理后台端
 * @param createType 新注册时间/迁入时间
 * @param fuHuaQiUscc 所属孵化器
 * @param industry 行业领域
 * @param isNaturalPersonHolding 自然人控股
 * @returns dataList
 */
async function outPutEnterpriseData(createType, fuHuaQiUscc, industry, isNaturalPersonHolding, type) {
    let selectParam = {};
    if (type == enum_1.OUTPUTTYPE.当前数据) {
        // if ( time.length > 0 ) {
        //     let startT = moment(time).startOf('month').valueOf();
        //     let endT = moment(time).endOf('month').valueOf();
        //     selectParam['$or'] = [
        //         {"firstIncubationTime":{'$gt':startT, '$lt':endT}},
        //         {"timeOfImmigration":{'$gt':startT, '$lt':endT}},
        //     ];
        // }
        // if (time) selectParam.logonTime = time; selectParam.timeOfImmigration = time;
        if (createType == 2 || createType == 3) {
            selectParam.createType = createType == 2 ? true : false;
        }
        if (fuHuaQiUscc)
            selectParam.fuHuaQiUscc = fuHuaQiUscc;
        if (industry.length > 0)
            selectParam.industry = industry;
        if (isNaturalPersonHolding == 2 || isNaturalPersonHolding == 3) {
            selectParam.isNaturalPersonHolding = isNaturalPersonHolding == 2 ? true : false;
        }
    }
    let usccMap = await fuhuaqi_1.findAllFuHuaQiOperationNameMap();
    let dataBaseList = await enterprise_1.findEnterpriseList(selectParam);
    let dataList = [];
    dataBaseList.forEach(info => {
        let changeData = tools_1.extractData(ojbectResultKeyConfig_2.EnterpriseListConfig, info, true);
        changeData.fuhuaqiUscc = usccMap[changeData.fuhuaqiUscc] || "";
        dataList.push(changeData);
    });
    return dataList;
}
exports.outPutEnterpriseData = outPutEnterpriseData;
async function getAffiliationFuHuaQi() {
    let dataList = [];
    let list = await enterprise_1.查询所有已绑定过的孵化器id();
    let allList = await fuhuaqi_1.findAllFuHuaQi();
    let distinctMap = {}; // {uscc:name}
    allList.forEach(info => {
        distinctMap[info.uscc] = info.name;
    });
    let result = [];
    list.forEach(fuHuaQiUscc => {
        let fuHuaQiName = distinctMap[fuHuaQiUscc];
        if (fuHuaQiName) {
            result.push({
                name: fuHuaQiName,
                uscc: fuHuaQiUscc
            });
        }
    });
    return { result };
}
exports.getAffiliationFuHuaQi = getAffiliationFuHuaQi;
//# sourceMappingURL=enterprise.js.map