"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.initTestSocketServer = exports.broadcastTestMsg = void 0;
const socket_server_1 = require("../../net/socket_server");
const log_1 = require("../../util/log");
//连接池
let connectionPool = {};
function space(lat1, lng1, lat2, lng2) {
    var radLat1 = lat1 * Math.PI / 180.0;
    var radLat2 = lat2 * Math.PI / 180.0;
    var a = radLat1 - radLat2;
    var b = lng1 * Math.PI / 180.0 - lng2 * Math.PI / 180.0;
    var s = 2 * Math.asin(Math.sqrt(Math.pow(Math.sin(a / 2), 2) +
        Math.cos(radLat1) * Math.cos(radLat2) * Math.pow(Math.sin(b / 2), 2)));
    s = s * 6378.137;
    s = Math.round(s * 10000) / 10000;
    return s; // 单位千米
}
// 获得角度的函数
function getAngle(start, end) {
    var ret;
    var w1 = start.lat / 180 * Math.PI;
    var j1 = start.lng / 180 * Math.PI;
    var w2 = end.lat / 180 * Math.PI;
    var j2 = end.lng / 180 * Math.PI;
    ret = 4 * Math.pow(Math.sin((w1 - w2) / 2), 2) - Math.pow(Math.sin((j1 - j2) / 2) * (Math.cos(w1) - Math.cos(w2)), 2);
    ret = Math.sqrt(ret);
    // var temp = Math.sin(Math.abs(j1 - j2) / 2) * (Math.cos(w1) + Math.cos(w2));
    var temp = Math.sin((j1 - j2) / 2) * (Math.cos(w1) + Math.cos(w2));
    ret = ret / temp;
    ret = Math.atan(ret) / Math.PI * 180;
    ret += 90;
    // 这里用如此臃肿的if..else是为了判定追踪单个点的具体情况,从而调整ret的值
    if (j1 - j2 < 0) {
        if (w1 - w2 >= 0) {
            ret = -ret + 180;
        }
    }
    else {
        if (w1 - w2 < 0) {
            ret = 180 + ret;
        }
        else {
            ret = -ret;
        }
    }
    return ret;
}
//广播消息
function broadcastTestMsg(vin, data) {
    let km = space(data.s.lat, data.s.lng, data.e.lat, data.e.lng);
    data.v = Math.ceil(km * 1000 / (data.t / 1000) * 1000) / 1000;
    data.ret = getAngle(data.s, data.e);
    if (!data.v)
        return;
    data.vin = vin;
    data.show = true;
    for (let key in connectionPool) {
        let result = { code: 200, success: true, data };
        try {
            console.log(data);
            connectionPool[key].send(JSON.stringify(result));
        }
        catch (err) {
            log_1.logError(`广播消息失败: ${err}`);
        }
    }
}
exports.broadcastTestMsg = broadcastTestMsg;
function analysisUserUrl(req) {
    let ip = req.headers['x-forwarded-for'] || req.connection.remoteAddress || req.socket.remoteAddress || req.connection.socket.remoteAddress;
    return ip;
}
async function initTestSocketServer(port) {
    socket_server_1.Socket.createServer(port, function (wss) {
        wss.on('connection', function (ws, req) {
            let ip = analysisUserUrl(req);
            connectionPool[ip] = ws;
            ws.on('message', function (data) {
                //回应心跳包
                if (data == 'i am heart')
                    ws.send(JSON.stringify({ success: true, code: 199 }));
            });
            ws.on('close', function (data) {
                if (ws._socket && ws._socket._peername && ws._socket._peername.address) {
                    let userId = ws._socket._peername.address;
                    console.log("close", userId);
                    delete connectionPool[userId];
                }
            });
            console.log(`测试服务链接成功  =>  userId:${ip}, 发送初始化车辆： 辆`);
            // initList.forEach(info => {
            //     ws.send(JSON.stringify({code:200, success:true, data:info}));
            // });
        });
    });
}
exports.initTestSocketServer = initTestSocketServer;
//# sourceMappingURL=testWsData.js.map