"use strict";
/**
 * 企业信息表
 * draftLock 草稿锁 当任务提交的时候，将此字段改为true
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.createEnterpriseToList = exports.查询所有已绑定过的孵化器id = exports.findEnterpriseListByFuHuaQiUsccName = exports.findEnterpriseInfoByName = exports.findEnterpriseCount = exports.findEnterpriseList = exports.findEnterpriseListToPage = exports.deleteEnterprise = exports.groupFindEnterprise = exports.findEnterpriseCountByFuHuaQiUscc = exports.createEnterprise = exports.updateEnterpriseDraftLock = exports.findEnterpriseListByTaskId = exports.findEnterpriseByUscc = exports.save = exports.initModel = void 0;
const mongoose_1 = require("mongoose");
const dbInit_1 = require("../../db/mongo/dbInit");
const enterpriseSchema = new mongoose_1.Schema({
    name: { type: String, index: true },
    taskId: { type: String, index: true },
    uscc: { type: String, index: true },
    fuHuaQiUscc: { type: String, index: true },
    industry: [Number],
    logonTime: Number,
    firstIncubationTime: Number,
    timeOfImmigration: Number,
    isNaturalPersonHolding: { type: Boolean, default: true },
    oldLogonAdd: String,
    logonAdd: String,
    operatingAdd: String,
    isCreate: { type: Boolean, default: false },
    // isPhysicalPresence:{type:Boolean, default:true},//是否实地孵化 暂时弃用
    leasedArea: Number,
    draftLock: { type: Boolean, default: false },
    createTime: Number, //录入时间
});
var enterpriseModel;
function initModel() {
    enterpriseModel = dbInit_1.baseDB.model('enterprise', enterpriseSchema);
    enterpriseModel.selectOnceData = async function (paramater) {
        let selectInfo = await enterpriseModel.findOne(paramater).exec();
        if (selectInfo) {
            if (!selectInfo.runSave) {
                selectInfo.runSave = selectInfo.save;
                selectInfo.save = save.bind(selectInfo);
            }
        }
        return selectInfo;
    };
}
exports.initModel = initModel;
async function save(throwError = false) {
    if (!this.isModified())
        return;
    await this.runSave({ validateBeforeSave: false }).catch(err => {
        console.log(err);
    });
}
exports.save = save;
/**
 * 通过企业统一信用代码获取企业信息
 * 支持.save方法保存对象修改
 * @param uscc 企业统一信用代码
 * @returns {}
 */
async function findEnterpriseByUscc(uscc) {
    return await enterpriseModel.selectOnceData({ uscc });
}
exports.findEnterpriseByUscc = findEnterpriseByUscc;
/**
 * 通过taskId 获取此次任务添加的企业列表
 * @param taskId 任务id 格式遵循tool中getTaskId
 * @returns [{}]
 */
async function findEnterpriseListByTaskId(taskId) {
    return await enterpriseModel.find({ taskId, draftLock: false });
}
exports.findEnterpriseListByTaskId = findEnterpriseListByTaskId;
/**
 * 将taskId的所有数据的draftLock字段为true
 * @param taskId 任务id 格式遵循tool中getTaskId
 */
async function updateEnterpriseDraftLock(taskId) {
    return await enterpriseModel.update({ taskId }, { $set: { draftLock: true } }, { upsert: true });
}
exports.updateEnterpriseDraftLock = updateEnterpriseDraftLock;
/**
 * 创建新的企业数据
 * @param fuHuaQiUscc 企业所属孵化器的统一信用代码
 * @param taskId 任务id 格式遵循tool中getTaskId
 * @param param 添加的字段对象
 */
async function createEnterprise(fuHuaQiUscc, taskId, param) {
    let addInfo = Object.assign({ fuHuaQiUscc, taskId, createTime: new Date().valueOf() }, param);
    await enterpriseModel.create(addInfo);
}
exports.createEnterprise = createEnterprise;
/**
 * 查找孵化器所拥有的企业数量
 * @param fuHuaQiUscc 孵化器统一信用代码
 * @returns number  孵化器拥有的企业数量
 */
async function findEnterpriseCountByFuHuaQiUscc(fuHuaQiUscc) {
    return await enterpriseModel.find({ fuHuaQiUscc }).count();
}
exports.findEnterpriseCountByFuHuaQiUscc = findEnterpriseCountByFuHuaQiUscc;
/**
 * 聚合查询 孵化器所拥有的企业数量
 * @returns {} key=孵化器统一信用 value=企业数量
 */
async function groupFindEnterprise() {
    let match = { draftLock: true }; //前置条件
    let dataList = await enterpriseModel.aggregate([{ $match: match }, { $group: { _id: "$fuHuaQiUscc", count: { $sum: 1 } } }]).exec();
    let result = {};
    dataList.forEach(info => {
        let { _id, count } = info;
        result[_id] = count;
    });
    return result;
}
exports.groupFindEnterprise = groupFindEnterprise;
/**
 * 删除创建企业的草稿报表
 * @param uscc 企业统一信用代码
 */
async function deleteEnterprise(uscc) {
    return await enterpriseModel.deleteOne({ uscc: uscc }).exec();
}
exports.deleteEnterprise = deleteEnterprise;
/**
 * 分页获取所有企业
 * @param selectParam 查询参数
 * @param skipCount 跳过数量
 * @returns [] 孵化器列表
 */
async function findEnterpriseListToPage(selectParam, skipCount) {
    return await enterpriseModel.find(selectParam).skip(skipCount).limit(10);
}
exports.findEnterpriseListToPage = findEnterpriseListToPage;
/**
 * 获取符合条件的所有企业
 * @param selectParam 查询参数
 * @param skipCount 跳过数量
 * @returns [] 孵化器列表
 */
async function findEnterpriseList(selectParam) {
    return await enterpriseModel.find(selectParam);
}
exports.findEnterpriseList = findEnterpriseList;
/**
 * 获取符合条件的企业数量
 * @param selectParam 查询参数
 * @returns number 数据数量
 */
async function findEnterpriseCount(selectParam) {
    return await enterpriseModel.find(selectParam).count();
}
exports.findEnterpriseCount = findEnterpriseCount;
/**
 * 通过企业名称获取企业信息
 * @param selectParam 查询参数
 * @returns number 数据数量
 */
async function findEnterpriseInfoByName(name) {
    return await enterpriseModel.findOne({ name });
}
exports.findEnterpriseInfoByName = findEnterpriseInfoByName;
/**
 * 获取孵化器下的所有企业信息
 * @param fuHuaQiUscc 孵化器统一信用代码
 * @returns []
 */
async function findEnterpriseListByFuHuaQiUsccName(fuHuaQiUscc) {
    return await enterpriseModel.find({ fuHuaQiUscc });
}
exports.findEnterpriseListByFuHuaQiUsccName = findEnterpriseListByFuHuaQiUsccName;
async function 查询所有已绑定过的孵化器id() {
    return await enterpriseModel.distinct('fuHuaQiUscc');
}
exports.查询所有已绑定过的孵化器id = 查询所有已绑定过的孵化器id;
async function createEnterpriseToList(fuHuaQiList) {
    await enterpriseModel.insertMany(fuHuaQiList);
}
exports.createEnterpriseToList = createEnterpriseToList;
//# sourceMappingURL=enterprise.js.map