"use strict";
/**
 * 企业投资信息表
 * draftLock 草稿锁 当任务提交的时候，将此字段改为true
 * 一个企业在一个月只能录入一个融资数据 2023-02-07 确定此需求
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.findFinancingList = exports.findFinancingCount = exports.findFinancingListToPage = exports.deleteEnterpriseFinancing = exports.createFinancing = exports.updateFinancingDraftLock = exports.findFinancingListByTaskId = exports.findFinancingInfoByTaskIdAndSucc = exports.save = exports.initModel = void 0;
const mongoose_1 = require("mongoose");
const dbInit_1 = require("../../db/mongo/dbInit");
const financingSchema = new mongoose_1.Schema({
    uscc: { type: String, index: true },
    fuHuaQiUscc: { type: String, index: true },
    name: String,
    taskId: { type: String, index: true },
    logonAdd: String,
    operatingAdd: String,
    financingAmount: Number,
    investmentInstitutionsName: String,
    timeToObtainInvestment: Number,
    fuHuaQiInvestment: { type: Boolean, default: false },
    fuHuaQiInvestmentAmount: Number,
    fuHuaQiInvestmentStyle: Number,
    draftLock: { type: Boolean, default: false },
    createTime: Number,
    industry: [Number],
    logonTime: Number, //注册时间
});
var financingModel;
function initModel() {
    financingModel = dbInit_1.baseDB.model('financing', financingSchema);
    financingModel.selectOnceData = async function (paramater) {
        let selectInfo = await financingModel.findOne(paramater).exec();
        if (selectInfo) {
            if (!selectInfo.runSave) {
                selectInfo.runSave = selectInfo.save;
                selectInfo.save = save.bind(selectInfo);
            }
        }
        return selectInfo;
    };
}
exports.initModel = initModel;
async function save(throwError = false) {
    if (!this.isModified())
        return;
    await this.runSave({ validateBeforeSave: false }).catch(err => {
        console.log(err);
    });
}
exports.save = save;
/**
 * 通过taskId和企业uscc获取融资信息
 * 支持.save方法保存对象修改
 * @param taskId 任务id 格式遵循tool中getTaskId
 * @param uscc 企业统一信用代码
 * @returns {}
 */
async function findFinancingInfoByTaskIdAndSucc(taskId, uscc) {
    return await financingModel.selectOnceData({ taskId, uscc });
}
exports.findFinancingInfoByTaskIdAndSucc = findFinancingInfoByTaskIdAndSucc;
/**
 * 通过taskId 获取此次任务添加的融资列表
 * @param taskId 任务id 格式遵循tool中getTaskId
 * @returns [{}]
 */
async function findFinancingListByTaskId(taskId) {
    return await financingModel.find({ taskId, draftLock: false });
}
exports.findFinancingListByTaskId = findFinancingListByTaskId;
/**
 * 将所有taskId匹配数据draftLock字段修改为true
 * @param taskId 任务id 格式遵循tool中getTaskId
 */
async function updateFinancingDraftLock(taskId) {
    return await financingModel.update({ taskId }, { $set: { draftLock: true } }, { upsert: true });
}
exports.updateFinancingDraftLock = updateFinancingDraftLock;
/**
 * 添加新的融资数据
 * @param fuHuaQiUscc 孵化器统一信用代码
 * @param taskId 任务id 格式遵循tool中getTaskId
 * @param param 所添加表单 需要提前验证
 */
async function createFinancing(fuHuaQiUscc, taskId, uscc, logonTime, param) {
    let addInfo = Object.assign({ fuHuaQiUscc, taskId, uscc, logonTime, createTime: new Date().valueOf() }, param);
    if (logonTime)
        addInfo.logonTime = logonTime;
    await financingModel.create(addInfo);
}
exports.createFinancing = createFinancing;
/**
 * 删除创建企业的草稿报表
 * @param uscc 企业统一信用代码
 * @param taskId 任务id
 */
async function deleteEnterpriseFinancing(uscc, taskId) {
    return await financingModel.deleteOne({ uscc: uscc, taskId }).exec();
}
exports.deleteEnterpriseFinancing = deleteEnterpriseFinancing;
/**
 * 分页获取所有融资企业
 * @param selectParam 查询参数
 * @param skipCount 跳过数量
 * @returns [] 孵化器列表
 */
async function findFinancingListToPage(selectParam, skipCount) {
    return await financingModel.find(selectParam).skip(skipCount).limit(10);
}
exports.findFinancingListToPage = findFinancingListToPage;
/**
 * 获取所有融资企业
 * @param selectParam 查询参数
 * @returns number 数据数量
 */
async function findFinancingCount(selectParam) {
    return await financingModel.find(selectParam).count();
}
exports.findFinancingCount = findFinancingCount;
/**
 * 获取所有融资企业
 * @param selectParam 查询参数
 * @param skipCount 跳过数量
 * @returns [] 孵化器列表
 */
async function findFinancingList(selectParam) {
    return await financingModel.find(selectParam);
}
exports.findFinancingList = findFinancingList;
//# sourceMappingURL=financing.js.map