"use strict";
/**
 * 孵化器月度填报表
 * draftLock 草稿锁 当任务提交的时候，将此字段改为true
 * occupancyRate 取%号前的数据 例如 填报数据为80%  库中数据为80
 * name 为系统生成 此月填报上一月内容 即2月填报时 name中月份为1月  2023-02-06 确定此需求
 *
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.createMonthTableToList = exports.findMonthTableListCount = exports.findMonthTableList = exports.findMonthTableListToPage = exports.deleteReport = exports.findMonthTableByTaskId = exports.findmonthTableListByTaskId = exports.save = exports.initModel = void 0;
const mongoose_1 = require("mongoose");
const dbInit_1 = require("../../db/mongo/dbInit");
const monthTableSchema = new mongoose_1.Schema({
    taskId: { type: String, index: true },
    name: String,
    fuHuaQiUscc: String,
    occupancyRate: Number,
    /**不下发字段 */
    draftLock: { type: Boolean, default: false },
    month: { type: Number, index: true },
    year: { type: Number, index: true },
    isUpdate: { type: Boolean, default: false },
    submitTime: Number, //提交时间
});
var monthTableModel;
function initModel() {
    monthTableModel = dbInit_1.baseDB.model('monthTable', monthTableSchema);
    monthTableModel.selectOnceData = async function (paramater) {
        let selectInfo = await monthTableModel.findOne(paramater).exec();
        if (selectInfo) {
            if (!selectInfo.runSave) {
                selectInfo.runSave = selectInfo.save;
                selectInfo.save = save.bind(selectInfo);
            }
        }
        return selectInfo;
    };
}
exports.initModel = initModel;
async function save(throwError = false) {
    if (!this.isModified())
        return;
    await this.runSave({ validateBeforeSave: false }).catch(err => {
        console.log(err);
    });
}
exports.save = save;
/**
 * 通过taskId 获取此次任务添加的月度列表
 * @param taskId 任务id 格式遵循tool中getTaskId
 * @returns {}
 */
async function findmonthTableListByTaskId(taskId) {
    return await monthTableModel.find({ taskId, isUpdate: true });
}
exports.findmonthTableListByTaskId = findmonthTableListByTaskId;
/**
 * 通过taskId 获取此次月度任务
 * 支持.save方法保存对象修改
 * @param taskId 任务id 格式遵循tool中getTaskId
 * @returns {}
 */
async function findMonthTableByTaskId(taskId) {
    let monthTableInfo = await monthTableModel.selectOnceData({ taskId });
    return monthTableInfo;
}
exports.findMonthTableByTaskId = findMonthTableByTaskId;
/**
 * 孵化器月度填报 删除报表
 * @param uscc 孵化器统一信用代码
 * @param name 表名称
 */
async function deleteReport(uscc, name) {
    return await monthTableModel.deleteOne({ fuHuaQiUscc: uscc, name }).exec();
}
exports.deleteReport = deleteReport;
/**
 * 分页查询符合条件的月度任务列表
 * @param selectParam  查询参数
 * @param skipNum 跳过数量
 * @returns []符合条件的月度列表
 */
async function findMonthTableListToPage(selectParam, skipNum) {
    return await monthTableModel.find(selectParam).skip(skipNum).limit(10);
}
exports.findMonthTableListToPage = findMonthTableListToPage;
/**
 * 查询符合条件的月度任务列表
 * @param selectParam  查询参数
 * @param skipNum 跳过数量
 * @returns []符合条件的月度列表
 */
async function findMonthTableList(selectParam) {
    return await monthTableModel.find(selectParam);
}
exports.findMonthTableList = findMonthTableList;
/**
 * 获取符合条件的月度任务列表数据量
 * @param selectParam  查询参数
 * @returns count 数据量
 */
async function findMonthTableListCount(selectParam) {
    return await monthTableModel.find(selectParam).count();
}
exports.findMonthTableListCount = findMonthTableListCount;
async function createMonthTableToList(tableList) {
    await monthTableModel.insertMany(tableList);
}
exports.createMonthTableToList = createMonthTableToList;
//# sourceMappingURL=monthTable.js.map