"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.findTaskListByType = exports.createTaskToList = exports.findTaskCountByKey = exports.findEnterpriseByTaskIdAndType = exports.findFuHuaQiTaskByTaskId = exports.save = exports.initModel = void 0;
/**
 * 孵化器任务表
 * 任务标识为 YYYYMM
 * 任务id 格式遵循tool中getTaskId
 * 每种任务一个月只能提交一次  2023-02-06 确定此需求
 * 任务提交之后将不会出现在列表中  2023-02-06 确定此需求
 * 任务不能提交后不能修改和删除 2023-02-06 确定此需求
 * type 依赖枚举
 */
const mongoose_1 = require("mongoose");
const dbInit_1 = require("../../db/mongo/dbInit");
const fuHuaQiTaskSchema = new mongoose_1.Schema({
    key: { type: Number, index: true },
    type: { type: Number, index: true },
    taskId: String,
    fuHuaQiUscc: String,
    submitTime: Number,
    // relevanceId:String,//任务关联的表 financing 或 enterprise 的id  弃用
    isSubmit: Boolean, //是否提交
});
var fuHuaQiTaskModel;
function initModel() {
    fuHuaQiTaskModel = dbInit_1.baseDB.model('fuHuaQiTask', fuHuaQiTaskSchema);
    fuHuaQiTaskModel.selectOnceData = async function (paramater) {
        let selectInfo = await fuHuaQiTaskModel.findOne(paramater).exec();
        if (selectInfo) {
            if (!selectInfo.runSave) {
                selectInfo.runSave = selectInfo.save;
                selectInfo.save = save.bind(selectInfo);
            }
        }
        return selectInfo;
    };
}
exports.initModel = initModel;
async function save(throwError = false) {
    if (!this.isModified())
        return;
    await this.runSave({ validateBeforeSave: false }).catch(err => {
        console.log(err);
    });
}
exports.save = save;
/**
 * 通过任务id 查询孵化器任务
 * @param taskId 任务id
 * @returns {1:{}, 2:{}}
 */
async function findFuHuaQiTaskByTaskId(taskId) {
    let findList = await fuHuaQiTaskModel.find({ taskId }).exec() || [];
    let taskMap = {};
    findList.forEach(item => {
        taskMap[item.type] = item;
    });
    return taskMap;
}
exports.findFuHuaQiTaskByTaskId = findFuHuaQiTaskByTaskId;
/**
 * 通过任务id和类型获取任务信息
 * 支持.save方法保存对象修改
 * @param taskId 任务id
 * @param type 任务类型
 * @returns {}
 */
async function findEnterpriseByTaskIdAndType(taskId, type) {
    return await fuHuaQiTaskModel.selectOnceData({ taskId, type });
}
exports.findEnterpriseByTaskIdAndType = findEnterpriseByTaskIdAndType;
async function findTaskCountByKey(key) {
    return await fuHuaQiTaskModel.find({ key }).count();
}
exports.findTaskCountByKey = findTaskCountByKey;
async function createTaskToList(taskList) {
    await fuHuaQiTaskModel.insertMany(taskList);
}
exports.createTaskToList = createTaskToList;
async function findTaskListByType(param) {
    let taskList = await fuHuaQiTaskModel.find(param);
    let map = {};
    taskList.forEach(info => {
        map[info.taskId] = info.isSubmit;
    });
    return map;
}
exports.findTaskListByType = findTaskListByType;
//# sourceMappingURL=task.js.map