"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getMap = void 0;
const errorEnum_1 = require("../../config/errorEnum");
const serverConfig_1 = require("../../config/serverConfig");
const bizError_1 = require("../../util/bizError");
const request_1 = require("../../util/request");
async function getMap() {
    let data = await request_1.get(serverConfig_1.appConfig.mapPort);
    if (!data)
        throw new bizError_1.BizError(errorEnum_1.ERRORENUM.未找到数据, "地图数据");
    let cameraData = [];
    let lidarData = [];
    let millimeterWaveRadarData = [];
    let RSUData = [];
    let SIBOXData = [];
    data.forEach(info => {
        let devType = info.devType || 0;
        let latitude = info.latitude || 0;
        let longitude = info.longitude || 0;
        let devname = info.devname || 0;
        let online = info.online ? 0 : 1;
        switch (devType) {
            case "摄像机":
                cameraData.push({ lat: latitude, lng: longitude, devname, state: online });
                break;
            case "激光雷达":
                lidarData.push({ lat: latitude, lng: longitude, devname, state: online });
                break;
            case "毫米波雷达":
                millimeterWaveRadarData.push({ lat: latitude, lng: longitude, devname, state: online });
                break;
            case "RSU":
                RSUData.push({ lat: latitude, lng: longitude, devname, state: online });
                break;
            case "信号机":
                SIBOXData.push({ lat: latitude, lng: longitude, devname, state: online });
                break;
        }
    });
    return { cameraData, lidarData, millimeterWaveRadarData, RSUData, SIBOXData };
}
exports.getMap = getMap;
//# sourceMappingURL=mapInterfaceData.js.map